# dh5 library

![Python 3.7+](https://img.shields.io/badge/python-3.7%2B-blue)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Install

`pip install dh5`

## Installation in dev mode

`pip install -e .[dev]`

or

`python setup.py develop`
